/*
 * Copyright (c) 2009 Lukas Mejdrech
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup socket
 *  @{
 */

/** @file
 */

#ifndef __NET_SOCKET_MESSAGES_H__
#define __NET_SOCKET_MESSAGES_H__

#include <ipc/ipc.h>

#include "../messages.h"

typedef enum{
	NET_SOCKET = NET_SOCKET_FIRST,
	NET_SOCKET_BIND,
	NET_SOCKET_LISTEN,
	NET_SOCKET_ACCEPT,
	NET_SOCKET_CONNECT,
	NET_SOCKET_CLOSE,
	NET_SOCKET_SEND,
	NET_SOCKET_SENDTO,
	NET_SOCKET_RECV,
	NET_SOCKET_RECVFROM,
	NET_SOCKET_GETSOCKOPT,
	NET_SOCKET_SETSOCKOPT,
	NET_SOCKET_ACCEPTED,
	NET_SOCKET_RECEIVED,
	NET_SOCKET_DATA_FRAGMENT_SIZE
} socket_messages;

#define SOCKET_SET_SOCKET_ID( call )		( int * ) & IPC_GET_ARG1( * call )
#define SOCKET_GET_SOCKET_ID( call )		( int ) IPC_GET_ARG1( * call )
#define SOCKET_SET_READ_DATA_LENGTH( call )	( int * ) & IPC_GET_ARG1( * call )
#define SOCKET_GET_READ_DATA_LENGTH( call )	( int ) IPC_GET_ARG1( * call )

#define SOCKET_SET_HEADER_SIZE( call )		( int * ) & IPC_GET_ARG2( * call )
#define SOCKET_GET_HEADER_SIZE( call )		( int ) IPC_GET_ARG2( * call )
#define SOCKET_GET_BACKLOG( call )			( int ) IPC_GET_ARG2( * call )
#define SOCKET_GET_OPT_LEVEL( call )		( int ) IPC_GET_ARG2( * call )
#define SOCKET_SET_DATA_FRAGMENTS( call )	( int * ) & IPC_GET_ARG2( * call )
#define SOCKET_GET_DATA_FRAGMENTS( call )	( int ) IPC_GET_ARG2( * call )

#define SOCKET_SET_DATA_FRAGMENT_SIZE( call )	( int * ) & IPC_GET_ARG3( * call )
#define SOCKET_GET_DATA_FRAGMENT_SIZE( call )	( int ) IPC_GET_ARG3( * call )

#define SOCKET_GET_FLAGS( call )			( int ) IPC_GET_ARG4( * call )

#define SOCKET_GET_OPT_NAME( call )			( int ) IPC_GET_ARG4( * call )



#endif

/** @}
 */
